# Copyright 2016 Grist Labs, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This module enhances the Python AST tree with token and source code information, sufficent to
detect the source text of each AST node. This is helpful for tools that make source code
transformations.
"""

from .line_numbers import LineNumbers
from .asttokens import ASTText, ASTTokens, supports_tokenless

__all__ = ['ASTText', 'ASTTokens', 'LineNumbers', 'supports_tokenless']



try:
  from astroid import nodes as astroid_node_classes

  # astroid_node_classes should be whichever module has the NodeNG class
  from astroid.nodes import NodeNG
  from astroid.nodes import BaseContainer
except Exception:
  try:
    from astroid import node_classes as astroid_node_classes
    from astroid.node_classes import NodeNG
    from astroid.node_classes import _BaseContainer as BaseContainer
  except Exception:  # pragma: no cover
    astroid_node_classes = None
    NodeNG = None
    BaseContainer = None


__all__ = ["astroid_node_classes", "NodeNG", "BaseContainer"]
